@@ -1,18 +1,18 @@
 
-# $Id: Advanced.pm,v 2.57 2007/04/14 18:14:50 Daddy Exp $
+# $Id: Advanced.pm,v 2.58 2007/04/21 17:09:49 Daddy Exp $
 
 =head1 NAME
 
-WWW::Search::Yahoo::News::Advanced - class for searching Yahoo! News
-using the "advanced" interface
+WWW::Search::Yahoo::News::Advanced - search Yahoo!News using the
+"advanced" interface
 
 =head1 SYNOPSIS
 
   use WWW::Search;
   my $oSearch = new WWW::Search('Yahoo::News::Advanced');
   my $sQuery = WWW::Search::escape_query("George Lucas");
-  $oSearch->date_from('2001-05-05');
-  $oSearch->date_to(  '2001-07-05');
+  $oSearch->date_from('7 days ago');
+  $oSearch->date_to  ('now');
   $oSearch->native_query($sQuery);
   while (my $oResult = $oSearch->next_result())
     print $oResult->url, "\n";
@@ -21,7 +21,7 @@ using the "advanced" interface
 
 This class is a Yahoo! News specialization of L<WWW::Search>.  It
 handles making and interpreting searches on Yahoo! News
-F<http://search.news.yahoo.com> using the Advanced search interface.
+F<http://news.yahoo.com> using the Advanced search interface.
 
 This class exports no public interface; all interaction should
 be done through L<WWW::Search> objects.
@@ -32,16 +32,10 @@ This backend supports narrowing the search by date-range.
 Use date_from() and date_to() to set the endpoints of the desired date range.
 You can use any date format supported by the Date::Manip module.
 
-If either date endpoint is not set explicitly,
-it will search with an appropriately open-ended date range.
+NOTE that Yahoo only seems to keep the last 60 days worth of news in its searchable index.
 
-NOTE that Yahoo only keeps the last 90 days worth of news in its index.
-
-ALSO NOTE that Yahoo will return an ERROR if date_from() is set to
-anything prior to Jan. 1 1999.  This backend does NOT check for that.
-
-News.yahoo.com dies if the unescaped query is longer than 485
-characters or so.  This backend does NOT check for that.
+At one time, News.yahoo.com would die if the unescaped query is longer
+than 485 characters or so.  This backend does NOT check for that.
 
 =head1 SEE ALSO
 
@@ -49,7 +43,8 @@ To make new back-ends, see L<WWW::Search>.
 
 =head1 BUGS
 
-Please tell the maintainer if you find any!
+To report a new bug, please use
+https://rt.cpan.org/Ticket/Create.html?Queue=WWW-Search-Yahoo
 
 =head1 AUTHOR
 
@@ -77,20 +72,23 @@ use WWW::Search::Yahoo;
 use strict;
 use vars qw( @ISA $VERSION $MAINTAINER );
 @ISA = qw( WWW::Search::Yahoo );
-$VERSION = do { my @r = (q$Revision: 2.57 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.58 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 
 sub native_setup_search
   {
   my ($self, $sQuery, $rh) = @_;
-  # print STDERR " +   in UK::native_setup_search, rh is ", Dumper($rh);
+  # print STDERR " +   in Y::N::A::native_setup_search, rh is ", Dumper($rh);
   my $sDateFrom = $self->date_from || '';
   my $sDateTo = $self->date_to || '';
   my $iUseDate = 0;
+  my ($iMonthFrom, $iDayFrom, $iMonthTo, $iDayTo);
   if ($sDateFrom ne '')
     {
     # User specified the beginning date.
-    $sDateFrom = &UnixDate(&ParseDate($sDateFrom), '%m/%d/%y');
+    my $dateFrom = &ParseDate($sDateFrom);
+    $iMonthFrom = &UnixDate($dateFrom, '%m');
+    $iDayFrom   = &UnixDate($dateFrom, '%d');
     $iUseDate = 1;
     }
   else
@@ -103,7 +101,9 @@ sub native_setup_search
   if ($sDateTo ne '')
     {
     # User specified the ending date.
-    $sDateTo = &UnixDate(&ParseDate($sDateTo), '%m/%d/%y');
+    my $date = &ParseDate($sDateTo);
+    $iMonthTo = &UnixDate($date, '%m');
+    $iDayTo   = &UnixDate($date, '%d');
     $iUseDate = 1;
     }
   else
@@ -111,30 +111,32 @@ sub native_setup_search
     # User did not specify the ending date.  Set it to the future:
     $sDateTo = &UnixDate(&ParseDate('tomorrow'), '%m/%d/%y');
     }
-  $self->{'_options'} = {
-                         'adv' => 1,
-                         # '1' => '', # this if for selecting sources
-                         # '2' => '', # this is number of days to search
-                         'c' => 'news',
-                         # 'cat' => '', # this is for selecting category
-                         'ei' => 'UTF-8',
-                         'n' => 100,  # 10 for testing, 100 for release
-                         'o' => 'o',  # OR of all words
-                         'p' => $sQuery,
-                         # I want to sort by descending relevance, but
-                         # yahoo.com is broken.  the 's' parameter in
-                         # the URL has no meaningful effect.
+  # With default search options:
+  # http://news.search.yahoo.com/search/news?p=Aomori&c=&ei=UTF-8&fl=0&n=100&x=wrt
 
-                         # 's' => '-s',  # sort order
+  $self->{'_options'} = {
+                         'ei' => 'UTF-8',
+                         'fl' => 0,
+                         'n' => 100,  # 10 for testing, 100 for release
+                         'p' => $sQuery,
                         };
   if ($iUseDate)
     {
-    $self->{'_options'}->{'3'} = qq{$sDateFrom-$sDateTo};
+    # This is the url when user chose date range:
+    # http://news.search.yahoo.com/search/news?ei=UTF-8&fr=&va=Aomori&va_vt=any&vp=&vp_vt=any&vo=&vo_vt=any&ve=&ve_vt=any&&pub=1&smonth=3&sday=22&emonth=3&eday=30&source=&location=&fl=0&n=100
+    $self->{'_options'}->{'pub'} = 1;
+    delete $self->{'_options'}->{'fl'};
+    delete $self->{'_options'}->{'p'};
+    $self->{'_options'}->{'va'} = $sQuery;
+    $self->{'_options'}->{'va_vt'} = 'any';
+    $self->{'_options'}->{'smonth'} = $iMonthFrom;
+    $self->{'_options'}->{'sday'} = $iDayFrom;
+    $self->{'_options'}->{'emonth'} = $iMonthTo;
+    $self->{'_options'}->{'eday'} = $iDayTo;
     } # if
-
-  $rh->{'search_base_url'} = 'http://search.news.yahoo.com';
+  $rh->{'search_base_url'} = 'http://news.search.yahoo.com';
   $rh->{'search_base_path'} = '/search/news/';
-  # print STDERR " +   Yahoo::UK::native_setup_search() is calling SUPER::native_setup_search()...\n";
+  # print STDERR " +   Y::N::A::native_setup_search() is calling SUPER::native_setup_search()...\n";
   return $self->SUPER::native_setup_search($sQuery, $rh);
   } # native_setup_search
 
@@ -226,3 +228,5 @@ A_TAG:
 
 __END__
 
+As of 2007-04:
+http://news.search.yahoo.com/search/news?ei=UTF-8&fr=&va=Aomori&va_vt=any&vp=&vp_vt=any&vo=&vo_vt=any&ve=&ve_vt=any&&pub=1&smonth=3&sday=22&emonth=3&eday=30&source=&location=&fl=0&n=100
